pub fn global_add_memory(start_vaddr: usize, size: usize) -> AllocResultExpand description
Add the given memory region to the global allocator.
Users should ensure that the region is valid and not being used by others, so that the allocated memory is also valid.
It’s similar to global_init, but can be called multiple times.
Arguments
start_vaddr: The starting virtual address of the memory region.size: The size of the memory region in bytes.